==> openshift-model-operator-5.4.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodeStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface NodeStatusFluent<A extends io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.Integer getCurrentRevision();
    public A withCurrentRevision(java.lang.Integer currentRevision);
    public java.lang.Boolean hasCurrentRevision();
    public java.lang.Integer getLastFailedRevision();
    public A withLastFailedRevision(java.lang.Integer lastFailedRevision);
    public java.lang.Boolean hasLastFailedRevision();
    public A addToLastFailedRevisionErrors(int index,java.lang.String item);
    public A setToLastFailedRevisionErrors(int index,java.lang.String item);
    public A addToLastFailedRevisionErrors(java.lang.String... items);
    public A addAllToLastFailedRevisionErrors(java.util.Collection<java.lang.String> items);
    public A removeFromLastFailedRevisionErrors(java.lang.String... items);
    public A removeAllFromLastFailedRevisionErrors(java.util.Collection<java.lang.String> items);
    public java.util.List<java.lang.String> getLastFailedRevisionErrors();
    public java.lang.String getLastFailedRevisionError(int index);
    public java.lang.String getFirstLastFailedRevisionError();
    public java.lang.String getLastLastFailedRevisionError();
    public java.lang.String getMatchingLastFailedRevisionError(java.util.function.Predicate<java.lang.String> predicate);
    public java.lang.Boolean hasMatchingLastFailedRevisionError(java.util.function.Predicate<java.lang.String> predicate);
    public A withLastFailedRevisionErrors(java.util.List<java.lang.String> lastFailedRevisionErrors);
    public A withLastFailedRevisionErrors(java.lang.String... lastFailedRevisionErrors);
    public java.lang.Boolean hasLastFailedRevisionErrors();
    public A addNewLastFailedRevisionError(java.lang.String arg0);
    public java.lang.String getNodeName();
    public A withNodeName(java.lang.String nodeName);
    public java.lang.Boolean hasNodeName();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withNodeName instead.
     */
        public A withNewNodeName(java.lang.String arg0);
    public java.lang.Integer getTargetRevision();
    public A withTargetRevision(java.lang.Integer targetRevision);
    public java.lang.Boolean hasTargetRevision();
}

==> openshift-model-operator-5.7.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodeStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface NodeStatusFluent<A extends io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.Integer getCurrentRevision();
    public A withCurrentRevision(java.lang.Integer currentRevision);
    public java.lang.Boolean hasCurrentRevision();
    public java.lang.Integer getLastFailedCount();
    public A withLastFailedCount(java.lang.Integer lastFailedCount);
    public java.lang.Boolean hasLastFailedCount();
    public java.lang.Integer getLastFailedRevision();
    public A withLastFailedRevision(java.lang.Integer lastFailedRevision);
    public java.lang.Boolean hasLastFailedRevision();
    public A addToLastFailedRevisionErrors(int index,java.lang.String item);
    public A setToLastFailedRevisionErrors(int index,java.lang.String item);
    public A addToLastFailedRevisionErrors(java.lang.String... items);
    public A addAllToLastFailedRevisionErrors(java.util.Collection<java.lang.String> items);
    public A removeFromLastFailedRevisionErrors(java.lang.String... items);
    public A removeAllFromLastFailedRevisionErrors(java.util.Collection<java.lang.String> items);
    public java.util.List<java.lang.String> getLastFailedRevisionErrors();
    public java.lang.String getLastFailedRevisionError(int index);
    public java.lang.String getFirstLastFailedRevisionError();
    public java.lang.String getLastLastFailedRevisionError();
    public java.lang.String getMatchingLastFailedRevisionError(java.util.function.Predicate<java.lang.String> predicate);
    public java.lang.Boolean hasMatchingLastFailedRevisionError(java.util.function.Predicate<java.lang.String> predicate);
    public A withLastFailedRevisionErrors(java.util.List<java.lang.String> lastFailedRevisionErrors);
    public A withLastFailedRevisionErrors(java.lang.String... lastFailedRevisionErrors);
    public java.lang.Boolean hasLastFailedRevisionErrors();
    public A addNewLastFailedRevisionError(java.lang.String arg0);
    public java.lang.String getLastFailedTime();
    public A withLastFailedTime(java.lang.String lastFailedTime);
    public java.lang.Boolean hasLastFailedTime();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withLastFailedTime instead.
     */
        public A withNewLastFailedTime(java.lang.String arg0);
    public java.lang.String getNodeName();
    public A withNodeName(java.lang.String nodeName);
    public java.lang.Boolean hasNodeName();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withNodeName instead.
     */
        public A withNewNodeName(java.lang.String arg0);
    public java.lang.Integer getTargetRevision();
    public A withTargetRevision(java.lang.Integer targetRevision);
    public java.lang.Boolean hasTargetRevision();
}
